---
title: 1D Comparison Split Ratio
---

![1D Comparison Split Ratio](../baseline/1d_comparison_split_ratio.png)

??? imports "Imports"
    ```python
    --8<--
    examples/1d_histograms/1d_comparison_split_ratio.py:imports
    --8<--
    ```

??? setup "Setup"
    ```python
    --8<--
    examples/1d_histograms/1d_comparison_split_ratio.py:setup
    --8<--
    ```

!!! tip "Code"
    ```python
    --8<--
    examples/1d_histograms/1d_comparison_split_ratio.py:plot_body
    --8<--
    ```

??? code "Full code"
    ```python
    --8<--
    examples/1d_histograms/1d_comparison_split_ratio.py:full_code
    --8<--
    ```
